@@ -1,4 +1,3 @@
-/* $Xorg: lcCT.c,v 1.4 2000/08/17 19:45:16 cpqbld Exp $ */
 /*
  * Copyright 1992, 1993 by TOSHIBA Corp.
  *
@@ -36,7 +35,6 @@
  *  Modifier: Ivan Pascal     The XFree86 Project
  *  Modifier: Bruno Haible    The XFree86 Project
  */
-/* $XFree86: xc/lib/X11/lcCT.c,v 3.26 2001/10/28 03:32:34 tsi Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -125,6 +123,8 @@ static const CTDataRec default_ct_data[] =
 #endif
     /* For use by utf8 -> ctext */
     { "BIG5-0:GLGR", "\033%/2"},
+    { "BIG5HKSCS-0:GLGR", "\033%/2"},
+    { "GBK-0:GLGR", "\033%/2"},
     /* used by Emacs, but not backed by ISO-IR */
     { "BIG5-E0:GL", "\033$(0" },
     { "BIG5-E0:GR", "\033$)0" },
@@ -1262,7 +1262,7 @@ open_cstostr(
 /* =========================== Initialization =========================== */
 
 Bool
-_XlcInitCTInfo()
+_XlcInitCTInfo(void)
 {
     if (ct_list == NULL) {
         const CTDataRec *ct_data;
